==> openshift-model-operator-5.12.4-sources.jar: io/fabric8/openshift/api/model/operator/v1/StorageStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class StorageStatusBuilder extends io.fabric8.openshift.api.model.operator.v1.StorageStatusFluentImpl<io.fabric8.openshift.api.model.operator.v1.StorageStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.StorageStatus,io.fabric8.openshift.api.model.operator.v1.StorageStatusBuilder>{
  public StorageStatusBuilder() {
    this(false);
  }
  public StorageStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new StorageStatus(), validationEnabled);
  }
  public StorageStatusBuilder(io.fabric8.openshift.api.model.operator.v1.StorageStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public StorageStatusBuilder(io.fabric8.openshift.api.model.operator.v1.StorageStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new StorageStatus(), validationEnabled);
  }
  public StorageStatusBuilder(io.fabric8.openshift.api.model.operator.v1.StorageStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.StorageStatus instance) {
    this(fluent, instance, false);
  }
  public StorageStatusBuilder(io.fabric8.openshift.api.model.operator.v1.StorageStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.StorageStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withGenerations(instance.getGenerations()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReadyReplicas(instance.getReadyReplicas()); 
    fluent.withVersion(instance.getVersion()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public StorageStatusBuilder(io.fabric8.openshift.api.model.operator.v1.StorageStatus instance) {
    this(instance,false);
  }
  public StorageStatusBuilder(io.fabric8.openshift.api.model.operator.v1.StorageStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withGenerations(instance.getGenerations()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReadyReplicas(instance.getReadyReplicas()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.StorageStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.StorageStatus build() {
    StorageStatus buildable = new StorageStatus(fluent.getConditions(),fluent.getGenerations(),fluent.getObservedGeneration(),fluent.getReadyReplicas(),fluent.getVersion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StorageStatusBuilder that = (StorageStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-6.5.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/StorageStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class StorageStatusBuilder extends StorageStatusFluentImpl<StorageStatusBuilder> implements VisitableBuilder<StorageStatus,StorageStatusBuilder>{
  public StorageStatusBuilder() {
    this(false);
  }
  public StorageStatusBuilder(Boolean validationEnabled) {
    this(new StorageStatus(), validationEnabled);
  }
  public StorageStatusBuilder(StorageStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public StorageStatusBuilder(StorageStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new StorageStatus(), validationEnabled);
  }
  public StorageStatusBuilder(StorageStatusFluent<?> fluent,StorageStatus instance) {
    this(fluent, instance, false);
  }
  public StorageStatusBuilder(StorageStatusFluent<?> fluent,StorageStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withGenerations(instance.getGenerations()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReadyReplicas(instance.getReadyReplicas()); 
    fluent.withVersion(instance.getVersion()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public StorageStatusBuilder(StorageStatus instance) {
    this(instance,false);
  }
  public StorageStatusBuilder(StorageStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withGenerations(instance.getGenerations()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReadyReplicas(instance.getReadyReplicas()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  StorageStatusFluent<?> fluent;
  Boolean validationEnabled;
  public StorageStatus build() {
    StorageStatus buildable = new StorageStatus(fluent.getConditions(),fluent.getGenerations(),fluent.getObservedGeneration(),fluent.getReadyReplicas(),fluent.getVersion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
